"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var path = require("path");
var parser_1 = require("../parser");
describe('parser', function () {
    it('Should parse class-based components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/Column.tsx'); // it's running in ./temp
        var result = parser_1.getDocumentation(fileName);
        chai_1.assert.ok(result.classes);
        chai_1.assert.ok(result.interfaces);
        chai_1.assert.equal(1, result.classes.length);
        chai_1.assert.equal(1, result.interfaces.length);
        var c = result.classes[0];
        chai_1.assert.equal('Column', c.name);
        chai_1.assert.equal('Form column.', c.comment);
        chai_1.assert.equal('Component', c.extends);
        var i = result.interfaces[0];
        chai_1.assert.equal('IColumnProps', i.name);
        chai_1.assert.equal('Column properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should parse functional components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/Row.tsx'); // it's running in ./temp
        var result = parser_1.getDocumentation(fileName);
        chai_1.assert.ok(result.classes);
        chai_1.assert.ok(result.interfaces);
        chai_1.assert.equal(1, result.classes.length);
        chai_1.assert.equal(1, result.interfaces.length);
        var c = result.classes[0];
        chai_1.assert.equal('Row', c.name);
        chai_1.assert.equal('Form row.', c.comment);
        chai_1.assert.equal('StatelessComponent', c.extends);
        var i = result.interfaces[0];
        chai_1.assert.equal('IRowProps', i.name);
        chai_1.assert.equal('Row properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
});
//# sourceMappingURL=parser.spec.js.map